@@ -36,7 +36,7 @@ def test_1d_renumber():
     assert np.all(data2 == [1,2,3,4,5,6,7,0])
     assert len(remapdict) > 0
 
-  data = np.arange(8).astype(np.bool)
+  data = np.arange(8).astype(bool)
   data = np.flip(data)
 
   data2 = np.copy(data)
@@ -129,6 +129,23 @@ def test_3d_renumber_dtype_shift():
   assert np.dtype(big.dtype).itemsize <= 4
   assert np.dtype(big.dtype).itemsize > 1
 
+def test_renumber_no_preserve_zero():
+  data = np.array([
+    [0, 1],
+    [1, 2]
+  ])
+  gt = np.array([
+    [0, 1],
+    [1, 2]
+  ])
+
+  res, remap = fastremap.renumber(data, start=0, preserve_zero=False)
+  print(res)
+  print(remap)
+  assert remap == { 0: 0, 1: 1, 2: 2 }
+  assert np.all(res == gt)
+
+
 @pytest.mark.parametrize("dtype", list(DTYPES) + [ np.float32, np.float64 ])
 def test_remap_1d(dtype):
   empty = fastremap.remap([], {})
@@ -222,7 +239,7 @@ def test_mask_except(dtype, in_place):
       20: 1,
     }
 
-@pytest.mark.parametrize("dtype", list(DTYPES) + [ np.float32, np.float64, np.bool, np.complex64 ])
+@pytest.mark.parametrize("dtype", list(DTYPES) + [ np.float32, np.float64, bool, np.complex64 ])
 @pytest.mark.parametrize("dim", [1, 4, 7, 9, 27, 31, 100, 127, 200] )
 def test_asfortranarray(dtype, dim):
   x = np.arange(dim**1).reshape((dim)).astype(dtype)
@@ -255,7 +272,7 @@ def test_asfortranarray(dtype, dim):
     assert np.all(np.asfortranarray(x) == fastremap.asfortranarray(y))
 
 
-@pytest.mark.parametrize("dtype", list(DTYPES) + [ np.float32, np.float64, np.bool, np.complex64 ])
+@pytest.mark.parametrize("dtype", list(DTYPES) + [ np.float32, np.float64, bool, np.complex64 ])
 @pytest.mark.parametrize("dim", [1, 4, 7, 9, 27, 31, 100, 127, 200] )
 def test_ascontiguousarray(dtype, dim):
   x = np.arange(dim**2).reshape((dim,dim), order='F').astype(dtype)
@@ -387,6 +404,8 @@ def test_unique(order):
       return np.asfortranarray(arr)
     return np.ascontiguousarray(arr)
 
+  assert len(fastremap.unique(np.array([], dtype=np.uint8))) == 0
+
   # array_unique
   labels = reorder(np.random.randint(0, 500, size=(128,128,128)))
   uniq_np, idx_np, cts_np = np.unique(labels, return_counts=True, return_index=True)
@@ -496,4 +515,47 @@ def test_inverse_component_map(dtype_cc, dtype_p):
   mapping = fastremap.inverse_component_map([ 1, 2, 1, 3 ], [ 4, 4, 5, 6 ])
   assert mapping == { 1: [ 4, 5 ], 2: [ 4 ], 3: [ 6 ] }
 
+  mapping = fastremap.inverse_component_map([ 1, 1, 1, 3 ], [ 4, 4, 5, 6 ]) 
+  assert mapping == {1: [4, 5], 3: [6]}
+
+  mapping = fastremap.inverse_component_map([ 1, 1, 1, 1 ], [ 4, 2, 5, 6 ]) 
+  assert mapping == {1: [4, 2, 5, 6]}
+
   mapping = fastremap.inverse_component_map([], [])
+
+def test_point_cloud():
+  x = np.ones((2,2,2), dtype=np.uint8)
+  ptc = fastremap.point_cloud(x)
+  assert len(ptc) == 1
+
+  gt = np.array([
+    [0, 0, 0],
+    [0, 0, 1],
+    [0, 1, 0],
+    [0, 1, 1],
+    [1, 0, 0],
+    [1, 0, 1],
+    [1, 1, 0],
+    [1, 1, 1],
+  ])
+  assert np.all(ptc[1] == gt)
+
+  x[0,0,0] = 2
+  ptc = fastremap.point_cloud(x)
+  assert len(ptc) == 2
+  assert np.all(ptc[1] == gt[1:,:])
+  assert np.all(ptc[2] == gt[:1,:])
+
+  x[1,1,1] = 3
+  ptc = fastremap.point_cloud(x)
+  assert len(ptc) == 3
+  assert np.all(ptc[1] == gt[1:7,:])
+  assert np.all(ptc[2] == gt[:1,:])
+  assert np.all(ptc[3] == gt[7:,:])  
+
+  x = np.ones((0,0,0), dtype=np.uint8)
+  ptc = fastremap.point_cloud(x)
+  assert len(ptc) == 0
+
+  
+
